ProjectQ - An open source software framework for quantum computing
==================================================================

Important
---------

This package offers the same functionality as the official `ProjectQ <https://pypi.org/project/projectq/>`__
package. It is however based on a development version that may contain some changes/bugfixes in order to better
integrate with other packages developped by `Huawei-HiQ <https://github.com/Huawei-HiQ>`__.
